==> unity-changeset-2.0.2.tgz: package/esm/unityChangeset.js <==
const REGEXP_HUB_LINK = /^unityhub:\/\/(\d{4}\.\d+\.\d+(a|b|f)\d+)\/(\w{12})$/;
const REGEXP_UNITY = /^(\d+)\.(\d+)\.(\d+)([a-zA-Z]+)(\d+)/;
const REGEXP_UNITY_NUM = /^(\d+)\.?(\d+)?\.?(\d+)?([a-zA-Z]+)?(\d+)?/;
/*
Unity Changeset
*/
export class UnityChangeset {
    constructor(version, changeset) {
        Object.defineProperty(this, "version", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "changeset", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "versionNumber", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: 0
        });
        Object.defineProperty(this, "minor", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "lifecycle", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "toString", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: () => {
                return `${this.version}\t${this.changeset}`;
            }
        });
        Object.assign(this, { version, changeset });
        const match = this.version.match(REGEXP_UNITY);
        if (match) {
            this.versionNumber = UnityChangeset.toNumber(this.version, false);
            this.minor = `${match[1]}.${match[2]}`;
            this.lifecycle = `${match[4]}`;
        }
    }
}
/*
 * Convert a Unity version to a number.
 */
Object.defineProperty(UnityChangeset, "isValid", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: (href) => {
        return REGEXP_HUB_LINK.test(href);
    }
});
Object.defineProperty(UnityChangeset, "createFromHref", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: (href) => {
        const match = href.match(REGEXP_HUB_LINK);
        return new UnityChangeset(match?.[1], match?.[3]);
    }
});
Object.defineProperty(UnityChangeset, "toNumber", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: (version, max) => {
        const match = version.toString().match(REGEXP_UNITY_NUM);
        if (match === null)
            return 0;
        return parseInt(match[1] || (max ? "9999" : "0")) * 100 * 100 * 100 * 100 +
            parseInt(match[2] || (max ? "99" : "0")) * 100 * 100 * 100 +
            parseInt(match[3] || (max ? "99" : "0")) * 100 * 100 +
            ((match[4] || (max ? "z" : "a")).toUpperCase().charCodeAt(0) - 65) * 100 +
            parseInt(match[5] || (max ? "99" : "0"));
    }
});

==> unity-changeset-2.1.2.tgz: package/esm/unityChangeset.js <==
const REGEXP_HUB_LINK = /^unityhub:\/\/(\d{4}\.\d+\.\d+(a|b|f)\d+)\/(\w{12})$/;
const REGEXP_UNITY = /^(\d+)\.(\d+)\.(\d+)([a-zA-Z]+)(\d+)/;
const REGEXP_UNITY_NUM = /^(\d+)\.?(\d+)?\.?(\d+)?([a-zA-Z]+)?(\d+)?/;
/*
Unity Changeset
*/
export class UnityChangeset {
    constructor(version, changeset, lts = false) {
        Object.defineProperty(this, "version", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "changeset", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "versionNumber", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: 0
        });
        Object.defineProperty(this, "minor", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "lifecycle", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "lts", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: false
        });
        Object.defineProperty(this, "toString", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: () => {
                return `${this.version}\t${this.changeset}`;
            }
        });
        Object.assign(this, { version, changeset, lts });
        const match = this.version.match(REGEXP_UNITY);
        if (match) {
            this.versionNumber = UnityChangeset.toNumber(this.version, false);
            this.minor = `${match[1]}.${match[2]}`;
            this.lifecycle = `${match[4]}`;
        }
    }
}
/*
 * Convert a Unity version to a number.
 */
Object.defineProperty(UnityChangeset, "isValid", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: (href) => {
        return REGEXP_HUB_LINK.test(href);
    }
});
Object.defineProperty(UnityChangeset, "createFromHref", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: (href) => {
        const match = href.match(REGEXP_HUB_LINK);
        return new UnityChangeset(match?.[1], match?.[3]);
    }
});
Object.defineProperty(UnityChangeset, "toNumber", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: (version, max) => {
        const match = version.toString().match(REGEXP_UNITY_NUM);
        if (match === null)
            return 0;
        return parseInt(match[1] || (max ? "9999" : "0")) * 100 * 100 * 100 * 100 +
            parseInt(match[2] || (max ? "99" : "0")) * 100 * 100 * 100 +
            parseInt(match[3] || (max ? "99" : "0")) * 100 * 100 +
            ((match[4] || (max ? "z" : "a")).toUpperCase().charCodeAt(0) - 65) * 100 +
            parseInt(match[5] || (max ? "99" : "0"));
    }
});
